==> ublock-origin_1.51.0+dfsg.orig.tar.xz: ublock-origin-1.51.0+dfsg/platform/mv3/safe-replace.js <==
/*******************************************************************************

    uBlock Origin - a browser extension to block requests.
    Copyright (C) 2017-present Raymond Hill

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see {http://www.gnu.org/licenses/}.

    Home: https://github.com/gorhill/uBlock
*/

'use strict';

/******************************************************************************/

export function safeReplace(text, pattern, replacement, count = 1) {
    const rePattern = typeof pattern === 'string'
        ? new RegExp(pattern.replace(/[.*+?^${}()|[\]\\]/g, '\\$&'))
        : pattern;
    let out = text;
    for (;;) {
        const match = rePattern.exec(out);
        if ( match === null ) { break; }
        out = out.slice(0, match.index) +
        replacement +
        out.slice(match.index + match[0].length);
        count -= 1;
        if ( count === 0 ) { break; }
    }
    return out;
}

==> ublock-origin_1.55.0+dfsg.orig.tar.xz: ublock-origin-1.55.0+dfsg/platform/mv3/safe-replace.js <==
/*******************************************************************************

    uBlock Origin - a comprehensive, efficient content blocker
    Copyright (C) 2017-present Raymond Hill

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see {http://www.gnu.org/licenses/}.

    Home: https://github.com/gorhill/uBlock
*/

'use strict';

/******************************************************************************/

export function safeReplace(text, pattern, replacement, count = 1) {
    const rePattern = typeof pattern === 'string'
        ? new RegExp(pattern.replace(/[.*+?^${}()|[\]\\]/g, '\\$&'))
        : pattern;
    let out = text;
    for (;;) {
        const match = rePattern.exec(out);
        if ( match === null ) { break; }
        out = out.slice(0, match.index) +
        replacement +
        out.slice(match.index + match[0].length);
        count -= 1;
        if ( count === 0 ) { break; }
    }
    return out;
}
